# Generated by Django 2.1.4 on 2018-12-20 17:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shopify_sync', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='carrierservice',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='collect',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='customcollection',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='customer',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='image',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='lineitem',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='metafield',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='option',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='order',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='product',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='scripttag',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='shop',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='smartcollection',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='variant',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='webhook',
            name='admin_graphql_api_id',
            field=models.CharField(default='', max_length=80),
            preserve_default=False,
        ),
    ]
