# Generated by Django 2.1.4 on 2019-01-07 16:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shopify_sync', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='product',
            name='body_html',
            field=models.TextField(default=''),
        ),
    ]
